@@ -635,7 +635,7 @@ def cohen_d(X, y, show = False, save_fig = ''):
     
     return d, IMG # d is a 1xn array. n is feature num
 
-def correlate(X,y, verbose = False):
+def correlate(X,y, verbose = False, show = False):
     """
     Performa correlation tests between each feature Xi and y.
     
@@ -678,6 +678,7 @@ def correlate(X,y, verbose = False):
         print(LOG)
 
     dct['correlation.r'] = rs
+    dct['correlation.r2'] = np.power(rs,2) # R2, the R-squared effect size
     dct['correlation.r.p'] = prs
     dct['correlation.r.max'] = np.abs(rs).max() # abs max
     dct['correlation.r.p.min'] = np.min(prs)
@@ -691,6 +692,16 @@ def correlate(X,y, verbose = False):
     dct['correlation.tau.p'] = ptaus
     dct['correlation.tau.max'] = np.abs(taus).max() # abs max
     dct['correlation.tau.p.min'] = np.min(ptaus)
+
+    if (show):
+
+        for key in ['correlation.r', 'correlation.r2', 'correlation.rho', 'correlation.tau']:
+            v = dct[key]
+            plt.figure(figsize=(40,5))
+            plt.bar(list(range(len(v))),v)
+            # plt.ylabel(key)
+            plt.title(key)
+            plt.show()
     
     return dct, LOG
 
